@@ -7,16 +7,34 @@ same tests multiple times.
 It achieves this by making classes have a ModifiedInstance object that discards
 any collected tests that aren't on that class.
 """
-from noseOfYeti.tokeniser.spec_codec import register
-
-from _pytest.unittest import UnitTestCase
-from unittest import mock
 import inspect
+from unittest import mock
+
 import pytest
+from _pytest.unittest import UnitTestCase
+
+from noseOfYeti.tokeniser.spec_codec import register
 
 
 def pytest_configure():
-    register()
+    register(transform=True)
+
+
+def change_item(res, obj):
+    original_item_collect = res.collect
+
+    if isinstance(res, UnitTestCase):
+
+        def collect():
+            yield from filter_collection(original_item_collect(), obj)
+
+    else:
+
+        def collect():
+            res.session._fixturemanager.parsefactories(res)
+            yield from filter_collection(original_item_collect(), obj)
+
+    mock.patch.object(res, "collect", collect).start()
 
 
 @pytest.hookimpl(hookwrapper=True)
@@ -25,33 +43,18 @@ def pytest_pycollect_makeitem(collector, name, obj):
     outcome = yield
     res = outcome.get_result()
 
-    if res is None:
+    if not isinstance(res, pytest.Class):
         return
 
-    if not hasattr(res, "obj"):
-        is_noy_on_obj = getattr(obj, "is_noy_spec", False)
-        is_noy_on_class = getattr(obj.__class__, "is_noy_spec", False)
-        if not is_noy_on_obj and not is_noy_on_class:
-            return
-
-    original_item_collect = res.collect
-
-    if isinstance(res, UnitTestCase):
-
-        def collect():
-            yield from filter_collection(original_item_collect(), res.obj)
-
-    else:
-
-        def collect():
-            res.session._fixturemanager.parsefactories(res)
-            yield from filter_collection(original_item_collect(), res.obj)
-
-    mock.patch.object(res, "collect", collect).start()
+    change_item(res, obj)
 
 
 def filter_collection(collected, obj):
     for thing in collected:
+        if not pytest.__version__.startswith("7") and isinstance(thing, pytest.Instance):
+            if getattr(thing.obj, "is_noy_spec", False):
+                change_item(thing, thing.obj)
+
         if not isinstance(thing, pytest.Function):
             yield thing
             continue
